"use strict";
/* @see https://tools.ietf.org/html/rfc4647#section-3.4
  Lookup is used to select the single language tag that best matches
  the language priority list for a given request.  When performing
  lookup, each language range in the language priority list is
  considered in turn, according to priority.  By contrast with
  filtering, each language range represents the most specific tag that
  is an acceptable match.  The first matching tag found, according to
  the user's priority, is considered the closest match and is the item
  returned.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.lookup = void 0;
function check(tag, range) {
    if (range === '*' || tag === range) {
        return true;
    }
    var pos = range.lastIndexOf('-');
    if (pos === -1) {
        return false;
    }
    if (pos > 3 && range.charAt(pos - 2) === '-') {
        pos -= 2;
    }
    range = range.substring(0, pos);
    return check(tag, range);
}
function matcher(tags, range) {
    return tags.find(function (tag) { return check(tag.toLowerCase(), range.toLowerCase()); });
}
function lookup(tags, ranges, defaultValue) {
    if (defaultValue === void 0) { defaultValue = 'en'; }
    if (!tags || !ranges)
        return defaultValue;
    tags = Array.isArray(tags) ? tags : [tags];
    ranges = Array.isArray(ranges) ? ranges : [ranges];
    for (var i = 0; i < ranges.length; i++) {
        // If the language range "*" is followed by other
        // language ranges, it is skipped.
        if (ranges[i] === '*')
            continue;
        var match = matcher(tags, ranges[i]);
        if (match)
            return match;
    }
    // If no language tag matches the
    // request, the "default" value is returned.
    return defaultValue;
}
exports.lookup = lookup;
